#!/usr/bin/env python
#-*- coding: utf-8 -*-
#Author: Colin
#Date: 2017-01-10
#Desc: 定义发送邮件的公共函数
#


from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from email.mime.image import MIMEImage

from colinws.colinwsLogs import printLog, warnLog
import smtplib
import os
import sys


class sendEmail():
	"""
	class for send out email by python.
	"""
	def __help(self):
		print("""

		you need excute below commands on you Linux system:
			export MAILHOST='smtp.xxx.com'
			export MAILUSER='XXX@mail.com'
			export MAILPASSWD='xxxxxxxxx'	

		""")


	def __init__(self, subject, content, mailto, attachment=None, images=None):
		"""
		initialize for class
		partA:
			get mail host/user/password from system variables 
			make sure you have added  these commands in /root/.bashrc file under centos

			export MAILHOST='smtp.xxx.com'
			export MAILUSER='XXX@mail.com'
			export MAILPASSWD='xxxxxxxxx'

		partB:
			self get params from class		
		"""
		

		## get system variables about mail
		if os.getenv('MAILHOST') is None or os.getenv('MAILUSER') is None or os.getenv('MAILPASSWD') is None:
			self.__help()
			sys.exit()
		else:
			self.MAILHOST = os.getenv('MAILHOST')
			self.MAILUSER = os.getenv('MAILUSER')
			self.MAILPASSWD = os.getenv('MAILPASSWD')
	

		self.subject = subject
		self.content = content
		self.mailto = mailto
		self.attachment = attachment		
		self.images = images 


	def __addIMG(self, src, imgid):
		"""
		params:
			src: the image filename with absolute or relative path
			imgid: for image object add_header function, the second param
		"""

		with open(src, 'rb') as fp:
			msgImage = MIMEImage(fp.read())
			msgImage.add_header('Content-ID', imgid)
			return msgImage


	def __addAttach(self, src):
		"""
		params:
			src: the attachment filename with absolute or relative path
		"""

		realname = os.path.basename(src)
		with open(src, 'rb') as fp:
			msgAttach = MIMEText(fp.read(), 'base64', 'utf-8')
			msgAttach['Content-Type'] = 'application/octet-stream'
			msgAttach['Content-Disposition'] = 'attachment; filename=' + str(realname)
			return msgAttach


	def sendMsg(self):
		"""
		send out email function
		"""
		
		msg = MIMEMultipart('related')
		
		msgContent = MIMEText(self.content, 'html', 'utf-8')
		msg.attach(msgContent)

		if self.attachment:
			if isinstance(self.attachment, list):
				for msgfile in self.attachment:
					msg.attach(self.__addAttach(msgfile))
		
		if self.images:
			if isinstance(self.images, list):
				for msgImage in self.images:
					msg.attach(self.__addIMG(msgImage['file'],msgImage['nameflag'] ))
					
		msg['Subject'] = self.subject
		msg['From'] = self.MAILUSER
		msg['To'] = self.mailto

		try:
			smtp = smtplib.SMTP()
			smtp.connect(self.MAILHOST)
			smtp.login(self.MAILUSER, self.MAILPASSWD)
			smtp.sendmail(self.MAILUSER, self.mailto.split(','), msg.as_string())
			smtp.close()
			printLog('send successfully!')
		except Exception as e:
			senderr = str(e)
			warnLog(senderr)



#!/usr/bin/env python
#-*- coding: utf-8 -*-
#Author: Colin
#Date: 2017-01-10
#Desc:
#


__author__ = 'Colin'
__version__ = '1.0.6'

from colinwsLogs import printLog, errorLog, warnLog
from colinwsDate import today, tommorrow, yesterday, daytime, dayBefore, dayAfter, firstAndLastDay
from colinwsEmail import sendEmail
from colinwsUtils import generate_passwd, getMD5, colorMsg

import sys

## private variables
_version = sys.version_info
_platform = sys.platform

## python2 or python3
is_py2 = (_version[0] == 2)
is_py3 = (_version[0] == 3)

## system 
is_linux = _platform.startswith('linux')
is_windows= _platform.startswith('win32')
is_osx = _platform.startswith('darwin')
is_linux = _platform.startswith('linux')


## difference between python2 and python3
if is_py2:
	unicode = unicode
	## basestring refer to str and unicode 
	basestring = basestring
	raw_input = raw_input
	xrange = xrange

if is_py3:
	unicode = str
	'''
	bytes and str in python3
	str.encode('utf-8') to bytes
	bytes.decode('utf-8') to str
	'''
	basestring = str
	raw_input = input
	xrange = range




#!/usr/bin/env python
#-*- coding: utf-8 -*-
#Author: Colin
#Date: 2017-01-10
#Desc: 定义一些主机相关的操作
#

import socket
import fcntl
import struct
import os
import commands

def getIPAdress(ifname='eth0'):
	'''
	利用Python socket模块 得到给定网口对应的当前主机的IP地址
	'''
	s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
	
	return socket.inet_ntoa(fcntl.ioctl(
			s.fileno(),
			0x8915,  # SIOCGIFADDR
			struct.pack('256s', ifname[:15]))[20:24])

def getIPAdress2():
	'''
	利用Linux命令`ip` 得到当前主机的IP
	'''
	_, ip = commands.getstatusoutput("""echo `/sbin/ip a | grep -E "eth[0-9]$|em[0-9]$|br[0-9]$|bond[0-9]$"|grep -E '[0-9]{1,3}/[0-9]{1,2}'| awk '{print $2}'|awk -F "/" '{print $1}'  | awk -F '.' '{print $0}'`""")
	return ip



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Author: Colin
# Date: 2017-05-11
# Desc: 自定义基础函数
#


import os
import sys
import hashlib 
import string
from random import choice

COLORS = {
	"reset": "\033[0m",
	"black": "\033[1;30m",
	'red': '\033[1;31m',
	'green': '\033[1;32m',
	'yellow': '\033[1;33m',
	'blue': '\033[1;34m',
	'magenta': '\033[1;35m',
	'cyan': '\033[1;36m',
	'white': '\033[1;37m',
	'bgred': '\033[1;41m',
	'bggrey': '\033[1;100m'
}


def colorMsg(color, msg):
	"""
	return msg with given color
	param color:
		black
		red
		green
		yellow
		blue
		magenta
		cyan
		white
		bgred
		bggrey
	"""
	return COLORS[color] + msg + COLORS['reset']


def getMD5(object):
	"""
	return hash value from file, string or folder
	"""
	md5_hash = None
	if os.path.isfile(object):
		with open(object, 'rb') as fd:
			md5_hash = hashlib.md5(fd.read()).hexdigest()
	elif os.path.isdir(object):
		md5_hash = hashlib.md5()
		for root, dirs, files in os.walk(object):
			#dirs[:] = sorted(dirs)
			for f in sorted(files):
				with open(os.path.join(root, f), 'rb') as fd:
					md5_hash.update(fd.read())
		md5_hash = md5_hash.hexdigest()
	elif isinstance(object, str):
		md5_hash = hashlib.md5(object).hexdigest()
	else:
		print(colorMsg('red', 'get MD5 for file or directory and please give right param'))

	return md5_hash

def generate_passwd():
	"""
	function to generate a password
	return passwd
	"""
	passwd = []
	passwd_length = 16
	passwd_seed = string.digits + string.ascii_letters + '!@#$%^&'

	while(len(passwd) < passwd_length):
		passwd.append(choice(passwd_seed))

	return ''.join(passwd)	


if __name__ == '__main__':
	msg = "Hello World"
	print(colorMsg('black', msg))
	print(colorMsg('red', msg))
	print(colorMsg('green', msg))
	print(colorMsg('yellow', msg))
	print(colorMsg('blue', msg))
	print(colorMsg('cyan', msg))
	print(colorMsg('magenta', msg))
	print(colorMsg('white', msg))
	print(colorMsg('bgred', msg))
	print(colorMsg('bggrey', msg))



#!/usr/bin/env python
#-*- coding: utf-8 -*-
#Author: Colin
#Date: 2017-04-20
#Desc: 自定义包设计到的初始化配置参数
#

import string 

PASSWD_LENGTH = 16
PASSWD_SEED = string.digits + string.ascii_letters + '!@#$%^&'



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Author: Colin
# Date: 2017-01-17
# Desc: 自定义带颜色的日志打印函数，按正常输出，错误，告警三个级别区别
#


from colinws.colinwsUtils import colorMsg

def printLog(string):
	"""
	func: greenPrint
	return: log with green color for info log
	"""
	print(colorMsg('green', string))
	#print("\033[32m" + string + "\033[0m")

def warnLog(string):
	"""
	func: warnLog
	return: log with yellow color for warning message show
	"""
	#print("\033[33m" + string + "\033[0m")
	print(colorMsg('yellow', string))

def errorLog(string):
	"""
	func: warnLog
	return: log with yellow color for error message show
	"""
	#print("\033[31m" + string + "\033[0m")
	print(colorMsg('red', string))


